.. image:: https://img.shields.io/pypi/v/vr.events.svg
   :target: https://pypi.org/project/vr.events

.. image:: https://img.shields.io/pypi/pyversions/vr.events.svg

.. image:: https://img.shields.io/pypi/dm/vr.events.svg

.. image:: https://img.shields.io/travis/yougov/vr.events/master.svg
   :target: http://travis-ci.org/yougov/vr.events

vr.events is a component of the `Velociraptor
<https://github.com/yougov/velociraptor>`_ project.

License
=======

License is indicated in the project metadata (typically one or more
of the Trove classifiers). For more details, see `this explanation
<https://github.com/jaraco/skeleton/issues/1>`_.

Docs
====

There's `no good mechanism for publishing documentation
<https://github.com/pypa/python-packaging-user-guide/pull/266>`_
easily. If there's a documentation link above, it's probably
stale because PyPI-based documentation is deprecated. This
project may have documentation published at ReadTheDocs, but
probably not. Good luck finding it.
